@@ -29,7 +29,7 @@ import sys
 
 
 # Initialise the constants.
-PYQT_VERSION_STR = "4.12.2"
+PYQT_VERSION_STR = "4.12.3"
 
 SIP_MIN_VERSION = '4.19.12'
 
@@ -2125,7 +2125,7 @@ def get_sip_flags(target_config):
     the target configuration.
     """
 
-    sip_flags = []
+    sip_flags = ['-n', 'PyQt4.sip']
 
     # If we don't check for signed interpreters, we exclude the 'VendorID'
     # feature
