@@ -28,8 +28,8 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x040c02
-pyqt_version_str = "4.12.2"
+pyqt_version = 0x040c03
+pyqt_version_str = "4.12.3"
 
 sip_min_version = 0x04130c
 
@@ -1425,7 +1425,7 @@ def set_sip_flags(pyqt):
 
     pyqt is the configuration instance.
     """
-    sip_flags = []
+    sip_flags = ['-n', 'PyQt4.sip']
 
     # If we don't check for signed interpreters, we exclude the 'VendorID'
     # feature
